Skip to contents

Access public spatial data from the Spanish Cadastre through its 'INSPIRE' and cadastral web services. Provides tools to download cadastral parcels, buildings, addresses and map images, and to geocode cadastral references.

Author

Maintainer: Diego Hernangómez diego.hernangomezherrero@gmail.com (ORCID)

Authors:

Other contributors:

  • Iñaki Ucar (ORCID) [contributor]