Create a table of URLs provided by the Spanish Cadastre ATOM INSPIRE service for downloading buildings.
catr_atom_get_buildings_db_all() provides a summary table with all
territorial offices, except the Basque Country and Navarre and the
municipalities included in each office. catr_atom_get_buildings_db_to()
provides a table for one territorial office and its municipalities.
Usage
catr_atom_get_buildings_db_all(
cache = deprecated(),
update_cache = FALSE,
cache_dir = NULL,
verbose = FALSE
)
catr_atom_get_buildings_db_to(
to,
cache = deprecated(),
update_cache = FALSE,
cache_dir = NULL,
verbose = FALSE
)Arguments
- cache
This argument is no longer supported because results are always cached.
- update_cache
Logical. Whether to refresh the cached file. Defaults to
FALSE.- cache_dir
Path to a cache directory. If
NULLorFALSE, the function stores cached files in a temporary directory. Seebase::tempdir().- verbose
Logical. If
TRUE, displays informational messages.- to
Character string. Territorial office to match using
base::grep().
Value
A tibble with the requested information in the following columns:
territorial_office: Territorial office, corresponding to each province of Spain except the Basque Country and Navarre.url: ATOM URL for the corresponding territorial office.munic: Name of the municipality.date: Reference date of the data. The information from this service is updated twice a year.
See also
Download data from ATOM INSPIRE services:
catr_atom_get_address(),
catr_atom_get_address_db_all(),
catr_atom_get_buildings(),
catr_atom_get_parcels(),
catr_atom_get_parcels_db_all(),
catr_atom_search_munic()
Work with cadastral buildings:
catr_atom_get_buildings(),
catr_wfs_get_buildings_bbox()
Examples
# \donttest{
catr_atom_get_buildings_db_all()
#> # A tibble: 7,611 × 4
#> territorial_office url munic date
#> <chr> <chr> <chr> <dttm>
#> 1 Territorial office 02 Albacete http://www.catastro… 0200… 2026-02-20 00:00:00
#> 2 Territorial office 02 Albacete http://www.catastro… 0200… 2026-02-20 00:00:00
#> 3 Territorial office 02 Albacete http://www.catastro… 0200… 2026-02-20 00:00:00
#> 4 Territorial office 02 Albacete http://www.catastro… 0200… 2026-02-20 00:00:00
#> 5 Territorial office 02 Albacete http://www.catastro… 0200… 2026-02-20 00:00:00
#> 6 Territorial office 02 Albacete http://www.catastro… 0200… 2026-02-20 00:00:00
#> 7 Territorial office 02 Albacete http://www.catastro… 0200… 2026-02-20 00:00:00
#> 8 Territorial office 02 Albacete http://www.catastro… 0200… 2026-02-20 00:00:00
#> 9 Territorial office 02 Albacete http://www.catastro… 0201… 2026-02-20 00:00:00
#> 10 Territorial office 02 Albacete http://www.catastro… 0201… 2026-02-20 00:00:00
#> # ℹ 7,601 more rows
# }