catr_atom_get_parcels: ATOM INSPIRE: Download all cadastral parcels of a...

View source: R/atom-cp.R

catr_atom_get_parcelsR Documentation

ATOM INSPIRE: Download all cadastral parcels of a municipality

Description

Retrieve the spatial data of all cadastral parcels belonging to a single municipality using the INSPIRE ATOM service.

Usage

catr_atom_get_parcels(
  munic,
  to = NULL,
  what = c("parcel", "zoning"),
  cache = deprecated(),
  update_cache = FALSE,
  cache_dir = NULL,
  verbose = FALSE
)

Arguments

munic

Municipality to extract, can be part of a string or a cadastral code. See catr_atom_search_munic() for getting the cadastral codes.

to

Optional argument for defining the territorial office to which munic belongs. This argument is a helper for narrowing the search.

what

Information to load. Options are:

  • "parcel" for cadastral parcels.

  • "zoning" for cadastral zoning.

cache

[Deprecated] cache is no longer supported, this function always caches results.

update_cache

logical, should the cached file be refreshed? Defaults to FALSE. When set to TRUE, it forces a new download.

cache_dir

Path to a cache directory. On NULL, the function stores cached files in a temporary directory (see base::tempdir()).

verbose

Logical. If TRUE, displays informational messages.

Value

A sf object.

References

API Documentation.

INSPIRE Services for Cadastral Cartography.

See Also

INSPIRE API functions: catr_atom_get_address(), catr_atom_get_address_db_all(), catr_atom_get_buildings(), catr_atom_get_buildings_db_all(), catr_atom_get_parcels_db_all(), catr_wfs_get_address_bbox(), catr_wfs_get_buildings_bbox(), catr_wfs_get_parcels_bbox(), catr_wms_get_layer(), inspire_wfs_get()

Other INSPIRE ATOM services: catr_atom_get_address(), catr_atom_get_address_db_all(), catr_atom_get_buildings(), catr_atom_get_buildings_db_all(), catr_atom_get_parcels_db_all(), catr_atom_search_munic()

Other parcels: catr_atom_get_parcels_db_all(), catr_wfs_get_parcels_bbox()

Other spatial: catr_atom_get_address(), catr_atom_get_buildings(), catr_wfs_get_address_bbox(), catr_wfs_get_buildings_bbox(), catr_wfs_get_parcels_bbox(), catr_wms_get_layer()

Examples



s <- catr_atom_get_parcels("Melque", to = "Segovia", what = "parcel")

library(ggplot2)

ggplot(s) +
  geom_sf() +
  labs(
    title = "Cadastral Parcels",
    subtitle = "Melque de Cercos, Segovia"
  )



CatastRo documentation built on April 27, 2026, 5:07 p.m.