| catr_atom_get_parcels_db_all | R Documentation |
Create a database containing the URLs provided in the INSPIRE ATOM service of the Spanish Cadastre for extracting cadastral parcels.
catr_atom_get_parcels_db_all() provides a top-level table
including information on all the territorial offices (except the
Basque Country and Navarre) listing the municipalities included in
each office.
catr_atom_get_parcels_db_to() provides a table for the specified
territorial office including information for each of the
municipalities of that office.
catr_atom_get_parcels_db_all(
cache = deprecated(),
update_cache = FALSE,
cache_dir = NULL,
verbose = FALSE
)
catr_atom_get_parcels_db_to(
to,
cache = deprecated(),
update_cache = FALSE,
cache_dir = NULL,
verbose = FALSE
)
A tibble with the information requested with the following fields:
territorial_office: territorial office, corresponding to each province
of Spain except the Basque Country and Navarre.
url: ATOM URL for the corresponding territorial office.
munic: Name of the municipality.
date: Reference date of the data. Note that the information from this
service is updated twice a year.
https://www.catastro.hacienda.gob.es/INSPIRE/CadastralParcels/ES.SDGC.CP.atom.xml
INSPIRE API functions:
catr_atom_get_address(),
catr_atom_get_address_db_all(),
catr_atom_get_buildings(),
catr_atom_get_buildings_db_all(),
catr_atom_get_parcels(),
catr_wfs_get_address_bbox(),
catr_wfs_get_buildings_bbox(),
catr_wfs_get_parcels_bbox(),
catr_wms_get_layer(),
inspire_wfs_get()
Other INSPIRE ATOM services:
catr_atom_get_address(),
catr_atom_get_address_db_all(),
catr_atom_get_buildings(),
catr_atom_get_buildings_db_all(),
catr_atom_get_parcels(),
catr_atom_search_munic()
Other parcels:
catr_atom_get_parcels(),
catr_wfs_get_parcels_bbox()
Other databases:
catr_atom_get_address_db_all(),
catr_atom_get_buildings_db_all(),
catr_atom_search_munic(),
catr_srs_values
catr_atom_get_parcels_db_all()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.