Skip to contents

Query the OVCCoordenadas Consulta RCCOOR service to retrieve the cadastral reference associated with a pair of coordinates.

Usage

catr_ovc_get_rccoor(lat, lon, srs = 4326, verbose = FALSE)

Arguments

lat

Latitude for the query, expressed in the SRS/CRS defined by srs.

lon

Longitude for the query, expressed in the SRS/CRS defined by srs.

srs

SRS/CRS to use in the query. To see allowed values, use catr_srs_values, specifically the ovc_service column.

verbose

Logical. If TRUE, displays informational messages.

Value

A tibble as described in Details. Returns NULL if the request fails.

Details

If the API returns no results, this function returns a tibble containing only query information.

On a successful query, this function returns a tibble with one row per cadastral reference, including the following columns:

  • geo.xcen, geo.ycen, geo.srs: Input arguments of the query.

  • refcat: Cadastral reference.

  • address: Address as recorded in the Spanish Cadastre.

  • Remaining fields: See the API documentation.

References

Consulta RCCOOR.

See also

Convert coordinates and cadastral references: catr_ovc_get_cpmrc(), catr_ovc_get_rccoor_distancia()

Work with cadastral references: catr_ovc_get_cpmrc(), catr_ovc_get_rccoor_distancia()

Examples

# \donttest{
catr_ovc_get_rccoor(
  lat = 38.6196566583596,
  lon = -3.45624183836806,
  srs = 4326
)
#>  The request could not be completed.
#> ! Failed to perform HTTP request.
#> Caused by error in `curl::curl_fetch_memory()`:
#> ! Failure when receiving data from the peer [ovc.catastro.meh.es]:
#> Recv failure: Connection reset by peer
#> → Returning "NULL" because the request failed.
#> NULL
# }