| catr_wfs_get_address_bbox | R Documentation |
Get the spatial data of addresses. The WFS Service allows performing several types of queries:
By bounding box: Implemented on catr_wfs_get_address_bbox().
Extract objects included in the bounding box provided. See
Bounding box.
By street code: Implemented on catr_wfs_get_address_codvia(). Extract
objects of specific addresses.
By cadastral reference: Implemented on catr_wfs_get_address_rc(). Extract
objects of specific cadastral references.
By postal codes: Implemented on catr_wfs_get_address_postalcode().
Extract objects of specific postal codes
catr_wfs_get_address_bbox(x, srs = NULL, verbose = FALSE)
catr_wfs_get_address_codvia(codvia, del, mun, srs = NULL, verbose = FALSE)
catr_wfs_get_address_rc(rc, srs = NULL, verbose = FALSE)
catr_wfs_get_address_postalcode(postalcode, srs = NULL, verbose = FALSE)
x |
See Bounding box. It may be:
|
srs |
SRS/CRS to use on the query. To see allowed values, use
catr_srs_values, specifically the |
verbose |
Logical. If |
codvia |
Cadastral street code. |
del |
Cadastral office code. |
mun |
Cadastral municipality code. |
rc |
The cadastral reference to be extracted. |
postalcode |
Postal code. |
A sf object.
The API service is limited to a bounding box of 4km2 and a maximum of 5,000 elements.
When x is a numeric vector, make sure that the srs matches the
coordinate values. Additionally, the function queries the bounding box on
EPSG:25830 - ETRS89 / UTM zone 30N, to overcome
a potential bug on the API side.
When x is a sf object, the value srs is ignored. In
this case, the bounding box of the sf object is
used for the query (see sf::st_bbox()).
The result is always provided in the SRS of the sf object
provided as input.
INSPIRE Services for Cadastral Cartography.
INSPIRE API functions:
catr_atom_get_address(),
catr_atom_get_address_db_all(),
catr_atom_get_buildings(),
catr_atom_get_buildings_db_all(),
catr_atom_get_parcels(),
catr_atom_get_parcels_db_all(),
catr_wfs_get_buildings_bbox(),
catr_wfs_get_parcels_bbox(),
catr_wms_get_layer(),
inspire_wfs_get()
Other INSPIRE WFS services:
catr_srs_values,
catr_wfs_get_buildings_bbox(),
catr_wfs_get_parcels_bbox(),
inspire_wfs_get()
Other addresses:
catr_atom_get_address(),
catr_atom_get_address_db_all()
Other spatial:
catr_atom_get_address(),
catr_atom_get_buildings(),
catr_atom_get_parcels(),
catr_wfs_get_buildings_bbox(),
catr_wfs_get_parcels_bbox(),
catr_wms_get_layer()
ad <- catr_wfs_get_address_bbox(
c(
233673, 4015968, 233761, 4016008
),
srs = 25830
)
library(ggplot2)
ggplot(ad) +
geom_sf()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.