| catr_wfs_get_parcels_bbox | R Documentation |
Get the spatial data of cadastral parcels and zones. The WFS Service allows several types of queries:
By bounding box: Implemented on catr_wfs_get_parcels_bbox(). Extract
objects included in the bounding box provided. See Bounding box.
By zoning: Implemented on catr_wfs_get_parcels_zoning(). Extract
objects of a specific cadastral zone.
By cadastral parcel: Implemented on catr_wfs_get_parcels_parcel().
Extract cadastral parcels of a specific cadastral reference.
Neighbor cadastral parcels: Implemented on
catr_wfs_get_parcels_neigh_parcel(). Extract neighbor cadastral parcels
of a specific cadastral reference.
Cadastral parcels by zoning: Implemented on
catr_wfs_get_parcels_parcel_zoning(). Extract cadastral parcels of a
specific cadastral zone.
catr_wfs_get_parcels_bbox(
x,
what = c("parcel", "zoning"),
srs = NULL,
verbose = FALSE
)
catr_wfs_get_parcels_zoning(cod_zona, srs = NULL, verbose = FALSE)
catr_wfs_get_parcels_parcel(rc, srs = NULL, verbose = FALSE)
catr_wfs_get_parcels_neigh_parcel(rc, srs = NULL, verbose = FALSE)
catr_wfs_get_parcels_parcel_zoning(cod_zona, srs = NULL, verbose = FALSE)
x |
See Bounding box. It may be:
|
what |
Information to load. Options are:
|
srs |
SRS/CRS to use on the query. To see allowed values, use
catr_srs_values, specifically the |
verbose |
Logical. If |
cod_zona |
Cadastral zone code. |
rc |
The cadastral reference to be extracted. |
A sf object.
The API service is limited to the following constraints:
"parcel: Bounding box of 1km2 and a maximum of 5,000 elements.
"zoning": Bounding box of 25km2 and a maximum of 5,000 elements.
When x is a numeric vector, make sure that the srs matches the
coordinate values. Additionally, the function queries the bounding box on
EPSG:25830 - ETRS89 / UTM zone 30N, to overcome
a potential bug on the API side.
When x is a sf object, the value srs is ignored. In
this case, the bounding box of the sf object is
used for the query (see sf::st_bbox()).
The result is always provided in the SRS of the sf object
provided as input.
INSPIRE Services for Cadastral Cartography.
INSPIRE API functions:
catr_atom_get_address(),
catr_atom_get_address_db_all(),
catr_atom_get_buildings(),
catr_atom_get_buildings_db_all(),
catr_atom_get_parcels(),
catr_atom_get_parcels_db_all(),
catr_wfs_get_address_bbox(),
catr_wfs_get_buildings_bbox(),
catr_wms_get_layer(),
inspire_wfs_get()
Other INSPIRE WFS services:
catr_srs_values,
catr_wfs_get_address_bbox(),
catr_wfs_get_buildings_bbox(),
inspire_wfs_get()
Other parcels:
catr_atom_get_parcels(),
catr_atom_get_parcels_db_all()
Other spatial:
catr_atom_get_address(),
catr_atom_get_buildings(),
catr_atom_get_parcels(),
catr_wfs_get_address_bbox(),
catr_wfs_get_buildings_bbox(),
catr_wms_get_layer()
cp <- catr_wfs_get_parcels_bbox(
c(
233673, 4015968, 233761, 4016008
),
srs = 25830
)
library(ggplot2)
ggplot(cp) +
geom_sf()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.