Skip to contents

Access public spatial data from the Spanish 'Catastro' through its Infrastructure for Spatial Information in Europe ('INSPIRE') and related web services. Retrieve parcel, building, address and map image data and convert between property reference codes and coordinates.

Author

Maintainer: Diego Hernangómez diego.hernangomezherrero@gmail.com (ORCID)

Authors:

Other contributors:

  • Iñaki Ucar (ORCID) [contributor]