CatastRo: Interface to the Spanish 'Catastro' Web Services
Source:R/CatastRo-package.R
CatastRo-package.RdAccess public spatial data from the Spanish Cadastre through its 'INSPIRE' and related web services. Retrieve cadastral parcel, building, address and georeferenced map image data and convert between cadastral references and coordinates.
Author
Maintainer: Diego Hernangómez diego.hernangomezherrero@gmail.com (ORCID)
Authors:
Diego Hernangómez diego.hernangomezherrero@gmail.com (ORCID)
Ángel Delgado Panadero delgadopanadero@gmail.com (ORCID) [copyright holder]
Other contributors:
Iñaki Ucar (ORCID) [contributor]