ATOM INSPIRE: download all addresses for a municipality
Source:R/atom-ad.R
catr_atom_get_address.RdRetrieve spatial data for all addresses in a municipality using the ATOM
INSPIRE service. The result also contains corresponding
street information in fields prefixed with tfname_*.
Usage
catr_atom_get_address(
munic,
to = NULL,
cache = deprecated(),
update_cache = FALSE,
cache_dir = NULL,
verbose = FALSE
)Arguments
- munic
Municipality name, partial name or cadastral code. Use
catr_atom_search_munic()to find cadastral codes.- to
Optional territorial office containing
munic. Use this argument to narrow the search.- cache
This argument is no longer supported because results are always cached.
- update_cache
Logical. Whether to refresh the cached file. Defaults to
FALSE.- cache_dir
Path to a cache directory. If
NULLorFALSE, the function stores cached files in a temporary directory. Seebase::tempdir().- verbose
Logical. If
TRUE, displays informational messages.
Value
An sf object. Returns NULL if the data cannot be
retrieved.
See also
Download data from ATOM INSPIRE services:
catr_atom_get_address_db_all(),
catr_atom_get_buildings(),
catr_atom_get_buildings_db_all(),
catr_atom_get_parcels(),
catr_atom_get_parcels_db_all(),
catr_atom_search_munic()
Work with cadastral addresses:
catr_atom_get_address_db_all(),
catr_wfs_get_address_bbox()