Skip to contents

Retrieve the spatial data of all addresses belonging to a single municipality using the INSPIRE ATOM service. The function also returns corresponding street information in fields prefixed with tfname_*.

Usage

catr_atom_get_address(
  munic,
  to = NULL,
  cache = deprecated(),
  update_cache = FALSE,
  cache_dir = NULL,
  verbose = FALSE
)

Arguments

munic

Municipality to extract. It can be a part of a string or the cadastral code. See catr_atom_search_munic() for getting the cadastral codes.

to

Optional parameter for defining the Territorial Office to which munic belongs. This parameter is a helper for narrowing the search.

cache

[Deprecated] cache is no longer supported; this function will always cache results.

update_cache

logical. Should the cached file be refreshed? Default is FALSE. When set to TRUE it would force a new download.

cache_dir

A path to a cache directory. On NULL the function would store the cached files on a temporary dir (See base::tempdir()).

verbose

logical. If TRUE displays informational messages.

Value

A sf object.

Examples

# \donttest{
s <- catr_atom_get_address("Melque",
  to = "Segovia"
)

library(ggplot2)

ggplot(s) +
  geom_sf(aes(color = specification)) +
  coord_sf(
    xlim = c(376200, 376850),
    ylim = c(4545000, 4546000)
  ) +
  labs(
    title = "Addresses",
    subtitle = "Melque de Cercos, Segovia"
  )

# }