Retrieve the spatial data of all addresses belonging to a single municipality
using the INSPIRE ATOM service. The function also returns corresponding
street information in fields prefixed with tfname_*.
Usage
catr_atom_get_address(
munic,
to = NULL,
cache = deprecated(),
update_cache = FALSE,
cache_dir = NULL,
verbose = FALSE
)Arguments
- munic
Municipality to extract. It can be a part of a string or the cadastral code. See
catr_atom_search_munic()for getting the cadastral codes.- to
Optional parameter for defining the Territorial Office to which
municbelongs. This parameter is a helper for narrowing the search.- cache
cacheis no longer supported; this function will always cache results.- update_cache
logical. Should the cached file be refreshed? Default is
FALSE. When set toTRUEit would force a new download.- cache_dir
A path to a cache directory. On
NULLthe function would store the cached files on a temporary dir (Seebase::tempdir()).- verbose
logical. If
TRUEdisplays informational messages.
Value
A sf object.
See also
INSPIRE API functions:
catr_atom_get_address_db_all(),
catr_atom_get_buildings(),
catr_atom_get_buildings_db_all(),
catr_atom_get_parcels(),
catr_atom_get_parcels_db_all(),
catr_wfs_get_address_bbox(),
catr_wfs_get_buildings_bbox(),
catr_wfs_get_parcels_bbox(),
catr_wms_get_layer(),
inspire_wfs_get()
Other INSPIRE ATOM services:
catr_atom_get_address_db_all(),
catr_atom_get_buildings(),
catr_atom_get_buildings_db_all(),
catr_atom_get_parcels(),
catr_atom_get_parcels_db_all(),
catr_atom_search_munic()
Other addresses:
catr_atom_get_address_db_all(),
catr_wfs_get_address_bbox()
Other spatial:
catr_atom_get_buildings(),
catr_atom_get_parcels(),
catr_wfs_get_address_bbox(),
catr_wfs_get_buildings_bbox(),
catr_wfs_get_parcels_bbox(),
catr_wms_get_layer()