Skip to contents

Retrieve the spatial data of all buildings belonging to a single municipality using the INSPIRE ATOM service.

Usage

catr_atom_get_buildings(
  munic,
  to = NULL,
  what = c("building", "buildingpart", "other"),
  cache = deprecated(),
  update_cache = FALSE,
  cache_dir = NULL,
  verbose = FALSE
)

Arguments

munic

Municipality to extract. It can be a part of a string or the cadastral code. See catr_atom_search_munic() for getting the cadastral codes.

to

Optional parameter for defining the Territorial Office to which munic belongs. This parameter is a helper for narrowing the search.

what

Information to load. It could be:

  • "building" for buildings.

  • "buildingpart" for parts of a building.

  • "other" for other elements, such as swimming pools, etc.

cache

[Deprecated] cache is no longer supported; this function will always cache results.

update_cache

logical. Should the cached file be refreshed? Default is FALSE. When set to TRUE it would force a new download.

cache_dir

A path to a cache directory. On NULL the function would store the cached files on a temporary dir (See base::tempdir()).

verbose

logical. If TRUE displays informational messages.

Value

A sf object.

Examples

# \donttest{
s <- catr_atom_get_buildings("Nava de la Asuncion",
  to = "Segovia",
  what = "building"
)

library(ggplot2)
ggplot(s) +
  geom_sf() +
  coord_sf(
    xlim = c(374500, 375500),
    ylim = c(4556500, 4557500)
  ) +
  labs(
    title = "Buildings",
    subtitle = "Nava de la Asuncion, Segovia"
  )

# }