Skip to contents

Retrieve spatial data for all cadastral parcels in a municipality using the ATOM INSPIRE service.

Usage

catr_atom_get_parcels(
  munic,
  to = NULL,
  what = c("parcel", "zoning"),
  cache = deprecated(),
  update_cache = FALSE,
  cache_dir = NULL,
  verbose = FALSE
)

Arguments

munic

Municipality name, partial name or cadastral code. Use catr_atom_search_munic() to find cadastral codes.

to

Optional territorial office containing munic. Use this argument to narrow the search.

what

Information to load. Options are:

  • "parcel" for cadastral parcels.

  • "zoning" for cadastral zoning.

cache

[Deprecated] This argument is no longer supported because results are always cached.

update_cache

Logical. Whether to refresh the cached file. Defaults to FALSE.

cache_dir

Path to a cache directory. If NULL or FALSE, the function stores cached files in a temporary directory. See base::tempdir().

verbose

Logical. If TRUE, displays informational messages.

Value

An sf object. Returns NULL if the data cannot be retrieved.

Examples

# \donttest{
s <- catr_atom_get_parcels("Melque", to = "Segovia", what = "parcel")

library(ggplot2)

ggplot(s) +
  geom_sf() +
  labs(
    title = "Cadastral parcels",
    subtitle = "Melque de Cercos, Segovia"
  )

# }