ATOM INSPIRE: download all cadastral parcels for a municipality
Source:R/atom-cp.R
catr_atom_get_parcels.RdRetrieve spatial data for all cadastral parcels in a municipality using the ATOM INSPIRE service.
Usage
catr_atom_get_parcels(
munic,
to = NULL,
what = c("parcel", "zoning"),
cache = deprecated(),
update_cache = FALSE,
cache_dir = NULL,
verbose = FALSE
)Arguments
- munic
Municipality name, partial name or cadastral code. Use
catr_atom_search_munic()to find cadastral codes.- to
Optional territorial office containing
munic. Use this argument to narrow the search.- what
Information to load. Options are:
"parcel"for cadastral parcels."zoning"for cadastral zoning.
- cache
This argument is no longer supported because results are always cached.
- update_cache
Logical. Whether to refresh the cached file. Defaults to
FALSE.- cache_dir
Path to a cache directory. If
NULLorFALSE, the function stores cached files in a temporary directory. Seebase::tempdir().- verbose
Logical. If
TRUE, displays informational messages.
Value
An sf object. Returns NULL if the data cannot be
retrieved.
See also
Download data from ATOM INSPIRE services:
catr_atom_get_address(),
catr_atom_get_address_db_all(),
catr_atom_get_buildings(),
catr_atom_get_buildings_db_all(),
catr_atom_get_parcels_db_all(),
catr_atom_search_munic()
Work with cadastral parcels:
catr_atom_get_parcels_db_all(),
catr_wfs_get_parcels_bbox()