ATOM INSPIRE: reference database for ATOM cadastral parcels
Source:R/atom-cp-db.R
catr_atom_get_parcels_db.RdCreate a database containing the URLs provided in the ATOM INSPIRE service of the Spanish Cadastre for extracting cadastral parcels.
catr_atom_get_parcels_db_all() provides a top-level table with all
territorial offices, except the Basque Country and Navarre, and the
municipalities included in each office. catr_atom_get_parcels_db_to()
provides a table for one territorial office and its municipalities.
Usage
catr_atom_get_parcels_db_all(
cache = deprecated(),
update_cache = FALSE,
cache_dir = NULL,
verbose = FALSE
)
catr_atom_get_parcels_db_to(
to,
cache = deprecated(),
update_cache = FALSE,
cache_dir = NULL,
verbose = FALSE
)Arguments
- cache
cacheis no longer supported, this function always caches results.- update_cache
Logical. Should the cached file be refreshed? Defaults to
FALSE. When set toTRUE, it forces a new download.- cache_dir
Path to a cache directory. On
NULL, the function stores cached files in a temporary directory (seebase::tempdir()).- verbose
Logical. If
TRUE, displays informational messages.- to
Character. Territorial office. Internally uses
base::grep()for matching.
Value
A tibble with the information requested with the following fields:
territorial_office: Territorial office, corresponding to each province of Spain except the Basque Country and Navarre.url: ATOM URL for the corresponding territorial office.munic: Name of the municipality.date: Reference date of the data. The information from this service is updated twice a year.
See also
Related INSPIRE API functions:
catr_atom_get_address(),
catr_atom_get_address_db_all(),
catr_atom_get_buildings(),
catr_atom_get_buildings_db_all(),
catr_atom_get_parcels(),
catr_wfs_get_address_bbox(),
catr_wfs_get_buildings_bbox(),
catr_wfs_get_parcels_bbox(),
catr_wms_get_layer(),
inspire_wfs_get()
Related ATOM INSPIRE functions:
catr_atom_get_address(),
catr_atom_get_address_db_all(),
catr_atom_get_buildings(),
catr_atom_get_buildings_db_all(),
catr_atom_get_parcels(),
catr_atom_search_munic()
Other parcels:
catr_atom_get_parcels(),
catr_wfs_get_parcels_bbox()
Other databases:
catr_atom_get_address_db_all(),
catr_atom_get_buildings_db_all(),
catr_atom_search_munic(),
catr_srs_values
Examples
# \donttest{
catr_atom_get_parcels_db_all()
#> # A tibble: 7,611 × 4
#> territorial_office url munic date
#> <chr> <chr> <chr> <dttm>
#> 1 Territorial office 02 Albacete http://www.catastro… 0200… 2026-02-20 00:00:00
#> 2 Territorial office 02 Albacete http://www.catastro… 0200… 2026-02-20 00:00:00
#> 3 Territorial office 02 Albacete http://www.catastro… 0200… 2026-02-20 00:00:00
#> 4 Territorial office 02 Albacete http://www.catastro… 0200… 2026-02-20 00:00:00
#> 5 Territorial office 02 Albacete http://www.catastro… 0200… 2026-02-20 00:00:00
#> 6 Territorial office 02 Albacete http://www.catastro… 0200… 2026-02-20 00:00:00
#> 7 Territorial office 02 Albacete http://www.catastro… 0200… 2026-02-20 00:00:00
#> 8 Territorial office 02 Albacete http://www.catastro… 0200… 2026-02-20 00:00:00
#> 9 Territorial office 02 Albacete http://www.catastro… 0201… 2026-02-20 00:00:00
#> 10 Territorial office 02 Albacete http://www.catastro… 0201… 2026-02-20 00:00:00
#> # ℹ 7,601 more rows
# }