catr_atom_search_munic: ATOM INSPIRE: Search for municipality codes

View source: R/atom-search.R

catr_atom_search_municR Documentation

ATOM INSPIRE: Search for municipality codes

Description

Search for a municipality (as a string, part of a string, or code) and get the corresponding code as per the Cadastre.

Usage

catr_atom_search_munic(
  munic,
  to = NULL,
  cache = deprecated(),
  update_cache = FALSE,
  cache_dir = NULL,
  verbose = FALSE
)

Arguments

munic

Municipality to extract, can be part of a string or a cadastral code. See catr_atom_search_munic() for getting the cadastral codes.

to

Optional argument for defining the territorial office to which munic belongs. This argument is a helper for narrowing the search.

cache

[Deprecated] cache is no longer supported, this function always caches results.

update_cache

logical, should the cached file be refreshed? Defaults to FALSE. When set to TRUE, it forces a new download.

cache_dir

Path to a cache directory. On NULL, the function stores cached files in a temporary directory (see base::tempdir()).

verbose

Logical. If TRUE, displays informational messages.

Value

A tibble.

See Also

Other INSPIRE ATOM services: catr_atom_get_address(), catr_atom_get_address_db_all(), catr_atom_get_buildings(), catr_atom_get_buildings_db_all(), catr_atom_get_parcels(), catr_atom_get_parcels_db_all()

Other search: catr_get_code_from_coords(), catr_ovc_get_cod_munic(), catr_ovc_get_cod_provinces()

Other databases: catr_atom_get_address_db_all(), catr_atom_get_buildings_db_all(), catr_atom_get_parcels_db_all(), catr_srs_values

Examples



catr_atom_search_munic("Mad")



CatastRo documentation built on April 27, 2026, 5:07 p.m.