| catr_clear_cache | R Documentation |
Use this function with caution. This function clears your cached data and configuration, specifically:
Deletes the CatastRo config directory
(tools::R_user_dir("CatastRo", "config")).
Deletes the cache_dir directory.
Deletes the values stored on Sys.getenv("CATASTROESP_CACHE_DIR").
catr_clear_cache(config = FALSE, cached_data = TRUE, verbose = FALSE)
config |
If |
cached_data |
If |
verbose |
Logical. If |
This is an overkill function that is intended to reset your status as if you had never installed and/or used CatastRo.
Invisible. This function is called for its side effects.
tools::R_user_dir()
Other cache utilities:
catr_set_cache_dir()
# Don't run this! It modifies your current state
## Not run:
my_cache <- catr_detect_cache_dir()
# Set an example cache
ex <- file.path(tempdir(), "example", "cache")
catr_set_cache_dir(ex, verbose = FALSE)
# Restore initial cache
catr_clear_cache(verbose = TRUE)
catr_set_cache_dir(my_cache)
identical(my_cache, catr_detect_cache_dir())
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.