| catr_ovc_get_cpmrc | R Documentation |
Implementation of the OVCCoordenadas service Consulta CPMRC. Returns coordinates for a specific cadastral reference.
catr_ovc_get_cpmrc(
rc,
srs = 4326,
province = NULL,
municipality = NULL,
verbose = FALSE
)
rc |
The cadastral reference to be geocoded. |
srs |
SRS/CRS to use on the query. To see allowed values, use
catr_srs_values, specifically the |
province, municipality |
Optional, used for narrowing the search. |
verbose |
Logical. If |
When the API does not provide any result, the function returns a tibble with the input arguments only.
On a successful query, the function returns a tibble with one row per cadastral reference, including the following columns:
xcoord, ycoord: X and Y coordinates in the specified SRS.
refcat: Cadastral Reference.
address: Address as recorded in the Cadastre.
Rest of fields: Check the API Docs.
A tibble. See Details
catr_srs_values, vignette("ovcservice", package = "CatastRo")
OVCCoordenadas API:
catr_ovc_get_rccoor(),
catr_ovc_get_rccoor_distancia(),
catr_srs_values
Other cadastral references:
catr_ovc_get_rccoor(),
catr_ovc_get_rccoor_distancia()
# Using all arguments
catr_ovc_get_cpmrc("13077A01800039",
4230,
province = "CIUDAD REAL",
municipality = "SANTA CRUZ DE MUDELA"
)
# Only the cadastral reference
catr_ovc_get_cpmrc("9872023VH5797S")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.