catr_ovc_get_rccoor: OVCCoordenadas: Reverse geocode a cadastral reference

View source: R/ovc-rccoor.R

catr_ovc_get_rccoorR Documentation

OVCCoordenadas: Reverse geocode a cadastral reference

Description

Implementation of the OVCCoordenadas service Consulta RCCOOR. Returns the cadastral reference found for a set of specific coordinates.

Usage

catr_ovc_get_rccoor(lat, lon, srs = 4326, verbose = FALSE)

Arguments

lat

Latitude for the query, expressed in the CRS/SRS defined by srs.

lon

Longitude for the query, expressed in the CRS/SRS defined by srs.

srs

SRS/CRS to use on the query. To see allowed values, use catr_srs_values, specifically the ovc_service column.

verbose

Logical. If TRUE, displays informational messages.

Details

When the API does not provide any result, the function returns a tibble with the input arguments only.

On a successful query, the function returns a tibble with one row by cadastral reference, including the following columns:

  • geo.xcen, geo.ycen, geo.srs: Input arguments of the query.

  • refcat: Cadastral Reference.

  • address: Address as recorded in the Cadastre.

  • Rest of fields: Check the API Docs.

Value

A tibble. See Details

References

Consulta RCCOOR.

See Also

catr_srs_values, vignette("ovcservice", package = "CatastRo")

OVCCoordenadas API: catr_ovc_get_cpmrc(), catr_ovc_get_rccoor_distancia(), catr_srs_values

Other cadastral references: catr_ovc_get_cpmrc(), catr_ovc_get_rccoor_distancia()

Examples



catr_ovc_get_rccoor(
  lat = 38.6196566583596,
  lon = -3.45624183836806,
  srs = 4326
)



CatastRo documentation built on April 27, 2026, 5:07 p.m.