| catr_ovc_get_rccoor | R Documentation |
Implementation of the OVCCoordenadas service Consulta RCCOOR. Returns the cadastral reference found for a set of specific coordinates.
catr_ovc_get_rccoor(lat, lon, srs = 4326, verbose = FALSE)
lat |
Latitude for the query, expressed in the CRS/SRS defined by
|
lon |
Longitude for the query, expressed in the CRS/SRS defined by
|
srs |
SRS/CRS to use on the query. To see allowed values, use
catr_srs_values, specifically the |
verbose |
Logical. If |
When the API does not provide any result, the function returns a tibble with the input arguments only.
On a successful query, the function returns a tibble with one row by cadastral reference, including the following columns:
geo.xcen, geo.ycen, geo.srs: Input arguments of the query.
refcat: Cadastral Reference.
address: Address as recorded in the Cadastre.
Rest of fields: Check the API Docs.
A tibble. See Details
catr_srs_values, vignette("ovcservice", package = "CatastRo")
OVCCoordenadas API:
catr_ovc_get_cpmrc(),
catr_ovc_get_rccoor_distancia(),
catr_srs_values
Other cadastral references:
catr_ovc_get_cpmrc(),
catr_ovc_get_rccoor_distancia()
catr_ovc_get_rccoor(
lat = 38.6196566583596,
lon = -3.45624183836806,
srs = 4326
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.