catr_ovc_get_rccoor_distancia: OVCCoordenadas: Reverse geocode cadastral references on a...

View source: R/ovc-rccoor-dist.R

catr_ovc_get_rccoor_distanciaR Documentation

OVCCoordenadas: Reverse geocode cadastral references on a region

Description

Implementation of the OVCCoordenadas service Consulta RCCOOR Distancia. Return cadastral references for coordinates. If none found, the API returns references in a 50 square meter area around the requested coordinates.

Usage

catr_ovc_get_rccoor_distancia(lat, lon, srs = 4326, verbose = FALSE)

Arguments

lat

Latitude for the query, expressed in the CRS/SRS defined by srs.

lon

Longitude for the query, expressed in the CRS/SRS defined by srs.

srs

SRS/CRS to use on the query. To see allowed values, use catr_srs_values, specifically the ovc_service column.

verbose

Logical. If TRUE, displays informational messages.

Details

When the API does not provide any result, the function returns a tibble with the input arguments only.

On a successful query, the function returns a tibble with one row by cadastral reference, including the following columns:

  • geo.xcen, geo.ycen, geo.srs: Input arguments of the query.

  • refcat: Cadastral reference.

  • address: Address as recorded in the Cadastre.

  • cmun_ine: Municipality code as registered on the INE (National Statistics Institute).

  • Rest of fields: Check the API Docs.

Value

A tibble. See Details

References

Consulta RCCOOR Distancia.

See Also

catr_srs_values, vignette("ovcservice", package = "CatastRo")

OVCCoordenadas API: catr_ovc_get_cpmrc(), catr_ovc_get_rccoor(), catr_srs_values

Other cadastral references: catr_ovc_get_cpmrc(), catr_ovc_get_rccoor()

Examples



catr_ovc_get_rccoor_distancia(
  lat = 40.963200,
  lon = -5.671420,
  srs = 4326
)



CatastRo documentation built on April 27, 2026, 5:07 p.m.