Skip to contents

Get the spatial data of addresses. The WFS Service allows performing several types of queries:

  • By bounding box: Implemented on catr_wfs_get_address_bbox(). Extract objects included in the bounding box provided. See Details.

  • By street code: Implemented on catr_wfs_get_address_codvia(). Extract objects of specific addresses.

  • By cadastral reference: Implemented on catr_wfs_get_address_rc(). Extract objects of specific cadastral references.

  • By postal codes: Implemented on catr_wfs_get_address_postalcode(). Extract objects of specific postal codes

Usage

catr_wfs_get_address_bbox(x, srs = NULL, verbose = FALSE)

catr_wfs_get_address_codvia(codvia, del, mun, srs = NULL, verbose = FALSE)

catr_wfs_get_address_rc(rc, srs = NULL, verbose = FALSE)

catr_wfs_get_address_postalcode(postalcode, srs = NULL, verbose = FALSE)

Arguments

x

See Details. It could be:

  • A numeric vector of length 4 with the coordinates that defines the bounding box: c(xmin, ymin, xmax, ymax)

  • A sf/sfc object, as provided by the sf package.

srs

SRS/CRS to use on the query. To check the admitted values check catr_srs_values, specifically the wfs_service column. See Details.

verbose

logical. If TRUE displays informational messages.

codvia

Cadastral street code.

del

Cadastral office code.

mun

Cadastral municipality code.

rc

The cadastral reference to be extracted.

postalcode

Postal code.

Value

A sf object.

Bounding box

When x is a numeric vector, make sure that the srs matches the coordinate values. Additionally, the function queries the bounding box on EPSG:25830 - ETRS89 / UTM zone 30N, to overcome a potential bug on the API side.

When x is a sf object, the value srs is ignored. In this case, the bounding box of the sf object would be used for the query (see sf::st_bbox()).

The result is always provided in the SRS of the sf object provided as input.

API Limits

The API service is limited to a bounding box of 4km2 and a maximum of 5.000 elements.

Examples

# \donttest{
ad <- catr_wfs_get_address_bbox(
  c(
    233673, 4015968, 233761, 4016008
  ),
  srs = 25830
)

library(ggplot2)

ggplot(ad) +
  geom_sf()

# }