Skip to contents

Retrieve spatial building data through two types of WFS queries:

  • By bounding box: catr_wfs_get_buildings_bbox() retrieves objects included in the provided bounding box. See Bounding box.

  • By cadastral reference: catr_wfs_get_buildings_rc() retrieves objects for specific cadastral references.

Usage

catr_wfs_get_buildings_bbox(
  x,
  what = c("building", "buildingpart", "other"),
  srs = NULL,
  verbose = FALSE
)

catr_wfs_get_buildings_rc(
  rc,
  what = c("building", "buildingpart", "other"),
  srs = NULL,
  verbose = FALSE
)

Arguments

x

Input defining the query area. See Bounding box. It can be:

  • A numeric vector of length 4 with the coordinates that define the bounding box: c(xmin, ymin, xmax, ymax).

  • An sf or sfc object from sf.

what

Information to load. Options are:

  • "building" for buildings.

  • "buildingpart" for parts of a building.

  • "other" for other elements such as swimming pools.

srs

SRS/CRS to use in the query. To see allowed values, use catr_srs_values, specifically the wfs_service column. See Bounding box.

verbose

Logical. If TRUE, displays informational messages.

rc

Cadastral reference to retrieve.

Value

An sf object. Returns NULL if the data cannot be retrieved.

API limits

The API service is limited to a bounding box of 4 km2 and a maximum of 5,000 elements.

Bounding box

When x is a numeric vector, make sure that the srs matches the coordinate values. Additionally, the function queries the bounding box on EPSG:25830, ETRS89 / UTM zone 30N, to work around a potential API issue.

When x is a sf object, the value srs is ignored. In this case, the bounding box of the sf object is used for the query (see sf::st_bbox()).

The result is always provided in the SRS of the sf object provided as input.

See also

Examples

# \donttest{
# Using a bounding box
building <- catr_wfs_get_buildings_bbox(
  c(
    376550,
    4545424,
    376600,
    4545474
  ),
  srs = 25830
)
library(ggplot2)
ggplot(building) +
  geom_sf() +
  labs(title = "Search using a bounding box")


# Using a cadastral reference
rc <- catr_wfs_get_buildings_rc("6656601UL7465N")
library(ggplot2)
ggplot(rc) +
  geom_sf() +
  labs(title = "Search using rc")

# }