Get the spatial data of cadastral parcels and zones. The WFS service allows several types of queries:
By bounding box:
catr_wfs_get_parcels_bbox()extracts objects included in the provided bounding box. See Bounding box.
By zoning:
catr_wfs_get_parcels_zoning()extracts objects for a specific cadastral zone.
By cadastral parcel:
catr_wfs_get_parcels_parcel()extracts cadastral parcels for a specific cadastral reference.
Neighbor cadastral parcels:
catr_wfs_get_parcels_neigh_parcel()extracts neighbor cadastral parcels for a specific cadastral reference.
Cadastral parcels by zoning:
catr_wfs_get_parcels_parcel_zoning()extracts cadastral parcels for a specific cadastral zone.
Usage
catr_wfs_get_parcels_bbox(
x,
what = c("parcel", "zoning"),
srs = NULL,
verbose = FALSE
)
catr_wfs_get_parcels_zoning(cod_zona, srs = NULL, verbose = FALSE)
catr_wfs_get_parcels_parcel(rc, srs = NULL, verbose = FALSE)
catr_wfs_get_parcels_neigh_parcel(rc, srs = NULL, verbose = FALSE)
catr_wfs_get_parcels_parcel_zoning(cod_zona, srs = NULL, verbose = FALSE)Arguments
- x
See Bounding box. Can be one of:
A numeric vector of length 4 with the coordinates that define the bounding box:
c(xmin, ymin, xmax, ymax).A
sf/sfcobject, as provided by the sf package.
- what
Information to load. Options are:
"parcel"for cadastral parcels."zoning"for cadastral zoning.
- srs
SRS/CRS to use in the query. To see allowed values, use catr_srs_values, specifically the
wfs_servicecolumn. See Bounding box.- verbose
Logical. If
TRUE, displays informational messages.- cod_zona
Cadastral zone code.
- rc
The cadastral reference to be extracted.
Value
A sf object.
API Limits
The API service is limited to the following constraints:
"parcel": Bounding box of 1 km2 and a maximum of 5,000 elements."zoning": Bounding box of 25 km2 and a maximum of 5,000 elements.
Bounding box
When x is a numeric vector, make sure that the srs matches the
coordinate values. Additionally, the function queries the bounding box on
EPSG:25830 - ETRS89 / UTM zone 30N, to overcome
a potential bug on the API side.
When x is a sf object, the value srs is ignored. In
this case, the bounding box of the sf object is
used for the query (see sf::st_bbox()).
The result is always provided in the SRS of the sf object
provided as input.
See also
Related INSPIRE API functions:
catr_atom_get_address(),
catr_atom_get_address_db_all(),
catr_atom_get_buildings(),
catr_atom_get_buildings_db_all(),
catr_atom_get_parcels(),
catr_atom_get_parcels_db_all(),
catr_wfs_get_address_bbox(),
catr_wfs_get_buildings_bbox(),
catr_wms_get_layer(),
inspire_wfs_get()
Related WFS INSPIRE functions:
catr_srs_values,
catr_wfs_get_address_bbox(),
catr_wfs_get_buildings_bbox(),
inspire_wfs_get()
Other parcels:
catr_atom_get_parcels(),
catr_atom_get_parcels_db_all()
Other spatial:
catr_atom_get_address(),
catr_atom_get_buildings(),
catr_atom_get_parcels(),
catr_wfs_get_address_bbox(),
catr_wfs_get_buildings_bbox(),
catr_wms_get_layer()