Get the spatial data of cadastral parcels and zones. The WFS Service allows to perform several types of queries:
By bounding box: Implemented on
catr_wfs_get_parcels_bbox(). Extract objects included in the bounding box provided. See Details.
By zoning: Implemented on
catr_wfs_get_parcels_zoning(). Extract objects of a specific cadastral zone.
By cadastral parcel: Implemented on
catr_wfs_get_parcels_parcel(). Extract cadastral parcels of a specific cadastral reference.
Neighbor cadastral parcels: Implemented on
catr_wfs_get_parcels_neigh_parcel(). Extract neighbor cadastral parcels of a specific cadastral reference.
Cadastral parcels by zoning: Implemented on
catr_wfs_get_parcels_parcel_zoning(). Extract cadastral parcels of a specific cadastral zone.
Usage
catr_wfs_get_parcels_bbox(
x,
what = c("parcel", "zoning"),
srs = NULL,
verbose = FALSE
)
catr_wfs_get_parcels_zoning(cod_zona, srs = NULL, verbose = FALSE)
catr_wfs_get_parcels_parcel(rc, srs = NULL, verbose = FALSE)
catr_wfs_get_parcels_neigh_parcel(rc, srs = NULL, verbose = FALSE)
catr_wfs_get_parcels_parcel_zoning(cod_zona, srs = NULL, verbose = FALSE)Arguments
- x
See Details. It could be:
A numeric vector of length 4 with the coordinates that defines the bounding box:
c(xmin, ymin, xmax, ymax)A
sf/sfcobject, as provided by the sf package.
- what
Information to load. It could be: -
"parcel"for cadastral parcels. -"zoning"for cadastral zoning.- srs
SRS/CRS to use on the query. To check the admitted values check catr_srs_values, specifically the
wfs_servicecolumn. See Details.- verbose
logical. If
TRUEdisplays informational messages.- cod_zona
Cadastral zone code.
- rc
The cadastral reference to be extracted.
Value
A sf object.
Details
When x is a numeric vector, make sure that the srs matches the
coordinate values. Additionally, when the srs corresponds to a geographic
reference system (4326, 4258), the function queries the bounding box on
EPSG:3857 - Web Mercator, to overcome
a potential bug on the API side. The result is always provided in the SRS
provided in srs.
When x is a sf object, the value srs is ignored. The
query is performed using EPSG:3857 (Web Mercator)
and the spatial object is projected back to the SRS of the initial object.
API Limits
The API service is limited to the following constraints:
"parcel: Bounding box of 1km2 and a maximum of 500 elements."zoning": Bounding box of 25km2 and a maximum of 500 elements.
See also
INSPIRE API functions:
catr_atom_get_address(),
catr_atom_get_address_db_all(),
catr_atom_get_buildings(),
catr_atom_get_buildings_db_all(),
catr_atom_get_parcels(),
catr_atom_get_parcels_db_all(),
catr_wfs_get_address_bbox(),
catr_wfs_get_buildings_bbox(),
catr_wms_get_layer(),
inspire_wfs_get()
Other INSPIRE WFS services:
catr_srs_values,
catr_wfs_get_address_bbox(),
catr_wfs_get_buildings_bbox(),
inspire_wfs_get()
Other parcels:
catr_atom_get_parcels(),
catr_atom_get_parcels_db_all()
Other spatial:
catr_atom_get_address(),
catr_atom_get_buildings(),
catr_atom_get_parcels(),
catr_wfs_get_address_bbox(),
catr_wfs_get_buildings_bbox(),
catr_wms_get_layer()